(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "@dripsy/core"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("@dripsy/core"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.core);
    global.size = mod.exports;
  }
})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function (_exports, _core) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.SizeDimension = void 0;
  _exports.useCalculateSize = useCalculateSize;

  function getAbsoluteSize(theme, size) {
    let absoluteSize = size;

    if (typeof size === "function") {
      absoluteSize = size(theme);
    }

    if (typeof absoluteSize === "string" && absoluteSize.length) {
      if (absoluteSize[absoluteSize.length - 1] === "%") {
        return absoluteSize;
      } else {
        const sizeNumber = parseInt(absoluteSize);
        return Number.isNaN(sizeNumber) ? sizeNumber : absoluteSize;
      }
    }

    return absoluteSize;
  }

  function useCalculateSize(size, orthogonalSize) {
    let ratio = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 16 / 9;
    let sizeDimension = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : SizeDimension.Width;
    const theme = (0, _core.useDripsyTheme)();
    size = getAbsoluteSize(theme, size);
    if (size && (typeof size !== "number" || size > 0)) return size;
    orthogonalSize = getAbsoluteSize(theme, orthogonalSize);

    if (typeof orthogonalSize === "number" && orthogonalSize > 0) {
      return sizeDimension === SizeDimension.Width ? orthogonalSize * ratio : orthogonalSize / ratio;
    }

    return size;
  }

  let SizeDimension;
  _exports.SizeDimension = SizeDimension;

  (function (SizeDimension) {
    SizeDimension[SizeDimension["Width"] = 0] = "Width";
    SizeDimension[SizeDimension["Height"] = 1] = "Height";
  })(SizeDimension || (_exports.SizeDimension = SizeDimension = {}));
});
//# sourceMappingURL=size.js.map